local AutoRoller = AutoRoller
local L = LibStub('AceLocale-3.0'):GetLocale('AutoRoller', true)

local function GetProfileValue(info)
   return info.handler.db.profile[info.arg]
end

local function SetProfileValue(info, value)
   info.handler.db.profile[info.arg] = value
end

local function GetCharValue(info)
   return info.handler.db.char[info.arg]
end

local function SetCharValue(info, value)
   info.handler.db.char[info.arg] = value
end

local function SetEnabled(info, v)
   local self = info.handler
   self.db.char.enabled = v
   if v then
      self:Enable()
   else
      self:Disable()
   end
end

AutoRoller.optionTable = {
   name = 'AutoRoller',
   desc = L["Automatically roll on items."],
   type = 'group',
   handler = AutoRoller,
   get = GetCharValue,
   set = SetCharValue,
   args = {
      desc = {
         name = L["Automatically roll on items."],
         type = 'description',
         order = 100,
         width = 'full',
      },
      [ENABLE] = {
         name = ENABLE,
         type = 'toggle',
         order = 200,
         get = 'IsEnabled',
         width = 'full',
         set = SetEnabled,
      },
      [CHAT] = {
         name = CHAT_OPTIONS_LABEL,
         desc = L["Output to chat when automatically rolling on an item."],
         type = 'toggle',
         order = 300,
         arg = 'chat',
      },
      disableBoPConfirm = {
         name = L["Hide BoP Confirmation"],
         desc = L["Hide the confirmation dialog that appears every time you roll on a bind on pickup item."],
         type = 'toggle',
         order = 350,
         arg = 'disableBoPConfirm',
      },
		[FILTERS] = {
			name = FILTERS,
			type = 'input',
			order = 400,
			width = 'full',
			multiline = true,
			arg = 'filter',
			get = GetProfileValue,
			set = SetProfileValue,
			validate = 'ValidateFilter',
		},
      [HELP_LABEL] = {
         name = L["TagHelp"],
         type = 'description',
         order = 500,
         width = 'full',
      }
   }
}

function AutoRoller:RegisterOptions()
   local options = self.optionTable
   local profile = LibStub('AceDBOptions-3.0'):GetOptionsTable(self.db)

   local registry = LibStub('AceConfigRegistry-3.0')
   local dialog = LibStub('AceConfigDialog-3.0')
   LibStub('AceConfig-3.0'):RegisterOptionsTable('AutoRoller', options, 'autoroller')

   registry:RegisterOptionsTable('AutoRoller Options', options)
   registry:RegisterOptionsTable('AutoRoller Profiles', profile)

   local main = dialog:AddToBlizOptions('AutoRoller Options', 'AutoRoller')
   dialog:AddToBlizOptions('AutoRoller Profiles', 'Profiles', 'AutoRoller')

   if self.dataobj then
      self.dataobj.OnClick = function() InterfaceOptionsFrame_OpenToCategory(main) end
   end
end
